<?php

/**
 * @package: events-venues-task
 * @author: Yevhen Odynets
 * @date: 2024-07-27
 * @time: 11:57
 */

declare(strict_types=1);

namespace App;

enum LoggingSeverityLevelsType
{
    /**
     * indicates that the system is unusable and requires immediate attention
     */
    case emergency;

    /**
     * indicates that immediate action is necessary to resolve a critical issue immediately
     * (such as a corrupted system database)
     */
    case alert;

    /**
     * signifies critical conditions in the program that demand intervention to prevent system failure
     */
    case critical;

    /**
     * indicates error conditions that impair some operation but are less severe than critical situations
     */
    case error;

    /**
     * signifies potential issues that may lead to errors or unexpected behavior in the future if not addressed
     */
    case warning;

    /**
     * applies to normal but significant conditions that may require monitoring
     */
    case notice;

    /**
     * includes messages that provide a record of the normal operation of the system
     */
    case info;

    /**
     * intended for logging detailed information about the system for debugging purposes
     */
    case debug;
}
